@@ -33,7 +33,7 @@ Readonly::Hash my %ACADVER => (
 	'AC1032' => 'AutoCAD 2018/2019/2020',
 );
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Constructor.
 sub new {
@@ -55,6 +55,18 @@ sub list_of_acad_identifiers {
 	return keys %ACADVER;
 }
 
+sub list_of_acad_identifiers_real {
+	my $self = shift;
+
+	my @mcs = sort grep { $_ =~ m/^MC/ms } keys %ACADVER;
+	my @ac_dot = sort grep { $_ =~ m/^AC\d+\.\d+$/ms } keys %ACADVER;
+	my @ac = sort grep { $_ =~ m/^AC\d+$/ms } keys %ACADVER;
+
+	my @ids = (@mcs, @ac_dot, @ac);
+
+	return @ids;
+}
+
 1;
 
 __END__
@@ -73,6 +85,7 @@ CAD::AutoCAD::Version - Class which work with AutoCAD versions.
 
  my $obj = CAD::AutoCAD::Version->new;
  my @acad_identifiers = $obj->list_of_acad_identifiers;
+ my @acad_identifiers_real = $obj->list_of_acad_identifiers_real;
 
 =head1 METHODS
 
@@ -86,7 +99,16 @@ Constructor.
 
  my @acad_identifiers = $obj->list_of_acad_identifiers;
 
-List AutoCAD identifiers user as DWG file magic string or $ACADVER in DXF file.
+List AutoCAD identifiers used as DWG file magic string or $ACADVER in DXF file.
+
+Returns array of identifiers.
+
+=head2 C<list_of_acad_identifiers_real>
+
+ my @acad_identifiers_real = $obj->list_of_acad_identifiers_real;
+
+List AutoCAD identifiers used as DWG file magic string or $ACADVER in DXF file.
+Ordered by date of AutoCAD releases.
 
 Returns array of identifiers.
 
@@ -96,7 +118,7 @@ Returns array of identifiers.
          From Class::Utils:
                  Unknown parameter '%s'.
 
-=head1 EXAMPLE
+=head1 EXAMPLE1
 
  use strict;
  use warnings;
@@ -138,6 +160,48 @@ Returns array of identifiers.
  #     [20] "MC0.0"
  # ]
 
+=head1 EXAMPLE2
+
+ use strict;
+ use warnings;
+
+ use Data::Printer;
+ use CAD::AutoCAD::Version;
+
+ # Object.
+ my $obj = CAD::AutoCAD::Version->new;
+
+ # Create image.
+ my @acad_identifiers_real = $obj->list_of_acad_identifiers_real;
+
+ # Print out type.
+ p @acad_identifiers_real;
+
+ # Output:
+ # [
+ #     [0]  "MC0.0"
+ #     [1]  "AC1.2",
+ #     [2]  "AC1.40",
+ #     [3]  "AC1.50",
+ #     [4]  "AC2.10",
+ #     [5]  "AC2.21",
+ #     [6]  "AC2.22",
+ #     [7]  "AC1001",
+ #     [8]  "AC1002",
+ #     [9]  "AC1003",
+ #     [10] "AC1004",
+ #     [11] "AC1006",
+ #     [12] "AC1009",
+ #     [13] "AC1012",
+ #     [14] "AC1014",
+ #     [15] "AC1015",
+ #     [16] "AC1018",
+ #     [17] "AC1021",
+ #     [18] "AC1024",
+ #     [19] "AC1027",
+ #     [20] "AC1032",
+ # ]
+
 =head1 DEPENDENCIES
 
 L<Class::Utils>,
@@ -161,6 +225,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
